@@ -179,6 +179,8 @@ class Form(object):
                             td = datetime.timedelta(seconds=int(value))
                             d = datetime.datetime(1, 1, 1) + td
                             serialized[name] = "%02d:%02d:%02d" % (d.hour, d.minute, d.second)
+                        elif ftype == "datetime":
+                            serialized[name] = value.strftime("%Y-%m-%d %H:%M:%S")
                         else:
                             serialized[name] = value
             except AttributeError:
@@ -259,9 +261,10 @@ class Form(object):
         # If we have a GET request than the user has loaded a exising
         # item (or wants to create a new one). In this case we will need
         # to get the initial data of the item an merge it with the
-        # provided values.
+        # provided values. This data is already serialized in the
+        # self.data attribute.
         else:
-            item_values = self.serialize(self.data)
+            item_values = self.data
             values.update(item_values)
 
         # Add csrf_token to the values dictionary
